@@ -41,5 +41,8 @@ class KccTemplateProcessor(TemplateProcessor):
             self.template_file = template_file_path
             if template_file_path:
                 template_json = yaml_from_file(file_path,loader=FullLoader)
-                self.contentType = 'yaml'
+                if template_json:
+                    self.contentType = 'yaml'
+                    if template_json.get("kind"):
+                        self.resource_types = [template_json.get("kind").lower()]
         return template_json
\ No newline at end of file
